@@ -1,5 +1,5 @@
-`bestsetNoise` <-
-function (m = 100, n = 40, method="exhaustive", nvmax=3) 
+bestsetNoise <-
+function (m = 100, n = 40, method = "exhaustive", nvmax = 3, print.summary=TRUE) 
 {
   leaps.out <- try(require(leaps), silent = TRUE)
   if ((is.logical(leaps.out) == TRUE) & (leaps.out == TRUE)) {
@@ -10,7 +10,7 @@ function (m = 100, n = 40, method="exhaustive", nvmax=3)
                     nbest = 1)
     x <- xx[, summary(u)$which[nvmax, -1]]
     u1 <- lm(y ~ x)
-    print(summary(u1, corr = FALSE))
+    if(print.summary) print(summary(u1, corr = FALSE))
     invisible(u1)
   }
   else {
